@@ -110,7 +110,7 @@ sub get_body_chunk {
 
   $self->emit('progress', 'body', $offset);
   my $chunk = $self->content->get_body_chunk($offset);
-  return $chunk if !defined $chunk || $chunk ne '';
+  return $chunk if !defined $chunk || length $chunk;
   $self->finish;
 
   return $chunk;
@@ -305,7 +305,7 @@ Mojo::Message - HTTP message base class
 
 =head1 DESCRIPTION
 
-L<Mojo::Message> is an abstract base class for HTTP message containers based on
+L<Mojo::Message> is an abstract base class for HTTP message containers, based on
 L<RFC 7230|http://tools.ietf.org/html/rfc7230>,
 L<RFC 7231|http://tools.ietf.org/html/rfc7231> and
 L<RFC 2388|http://tools.ietf.org/html/rfc2388>, like L<Mojo::Message::Request>
